@@ -1,8 +1,9 @@
 """Simple test for using adafruit_motorkit with a DC motor"""
 import time
+import board
 from adafruit_motorkit import MotorKit
 
-kit = MotorKit()
+kit = MotorKit(i2c=board.I2C())
 
 kit.motor1.throttle = 1.0
 time.sleep(0.5)
